@@ -154,6 +154,8 @@ pub struct Select {
     pub sort_by: Vec<Expr>,
     /// HAVING
     pub having: Option<Expr>,
+    /// QUALIFY (Snowflake)
+    pub qualify: Option<Expr>,
 }
 
 impl fmt::Display for Select {
@@ -202,6 +204,9 @@ impl fmt::Display for Select {
         if let Some(ref having) = self.having {
             write!(f, " HAVING {}", having)?;
         }
+        if let Some(ref qualify) = self.qualify {
+            write!(f, " QUALIFY {}", qualify)?;
+        }
         Ok(())
     }
 }
@@ -649,6 +654,7 @@ impl fmt::Display for Values {
 pub struct SelectInto {
     pub temporary: bool,
     pub unlogged: bool,
+    pub table: bool,
     pub name: ObjectName,
 }
 
@@ -656,7 +662,8 @@ impl fmt::Display for SelectInto {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         let temporary = if self.temporary { " TEMPORARY" } else { "" };
         let unlogged = if self.unlogged { " UNLOGGED" } else { "" };
+        let table = if self.table { " TABLE" } else { "" };
 
-        write!(f, "INTO{}{} {}", temporary, unlogged, self.name)
+        write!(f, "INTO{}{}{} {}", temporary, unlogged, table, self.name)
     }
 }
